# Provider guides 

These guides give directions for obtaining API keys from different providers. 

Here are the instructions for:
- [Anthropic](anthropic.md) 
- [AWS](aws.md)
- [Azure](azure.md) 
- [Cohere](cohere.md)
- [Google](google.md)
- [Hugging Face](huggingface.md)
- [OpenAI](openai.md)
- [SambaNova](sambanova.md)
- [xAI](xai.md)

Unless otherwise stated, these guides have not been endorsed by the providers. 

We also welcome additional [contributions](../CONTRIBUTING.md). 

